---
title: 'HOSR Core Rules: Adventuring'
description:
date_pub: 2023-04-26T23:02:00-04:00
section: rules
content_type: feature
short_code: uha
---

[[toc]]

### Introduction

In general, playing an RPG powered by HOSR comes down to running through a series of linked procedures or "game loops":

1.  **Setup**: GM determines the current situation (often using dice and tables), and describes it to the players.
2.  **Response**: Players explain how they want to react to the situation, and make any checks that the GM calls for.
3.  **Repeat**: Return to step 1 and repeat until the adventuring ends.

Some examples of these loops include the [Exploration Procedure](#exploration-procedure) or [Encounter Prodcedure](#encounter-procedure).

### Ability Checks

Simple tasks are assumed to succeed. If the task is dangerous or complicated, roll the dice for an Ability Check.

For most checks, roll a 20-sided die (d20) and add the ability's modifier.

<div class="dividedTableWrapper" id="ability-modifier-table">

| Ability | Mod |
| :-----: | :-: |
|    3    | -3  |
|   4-5   | -2  |
|   6-8   | -1  |
|  9-12   | +0  |
|  13-15  | +1  |
|  16-17  | +2  |
|   18+   | +3  |

[Ability Modifier]

</div>

-   The GM may also add a situational modifier to the roll, typically between -4 and +4.

Then, check the results of the roll:

<div class="dividedTableWrapper">

|           Roll           |       Result        |
| :----------------------: | :-----------------: |
|    25+ or natural 20     |  Critical Success   |
|          11-24           |  Complete Success   |
|           6-10           | Complicated Success |
|        5 or less         |       Failure       |
| Less than 0 or natural 1 |       Fumble        |

[Ability Check Result]

</div>

-   A natural 20 or a result of 25 or more is a **Critical Success**: the check succeeds, and often includes a bonus for the roller.
-   An 11-24 indicates a **Complete Success**: the check succeeds.
-   A 6-10 represents a **Complicated Success**: the check succeeds, but with a potential [complication](#complications) or challenge for the roller.
-   A 5 or less is a **Failure**: the check fails.
-   A natural 1 or a result of less than 0 is a **Fumble**: the check fails, and often includes an extra complication or challenge for the roller.

#### Skilled Ability Checks

Many classes have unique skills which PCs learn as they gain levels in those classes.

<div class="dividedTableWrapper" id="class-level-modifier-table">

| Class Level | Mod |   Term   |
| :---------: | :-: | :------: |
|     1-3     |  0  | Beginner |
|     4-6     | +1  | Skilled  |
|     7-9     | +2  | Advanced |
|    10-12    | +3  |  Expert  |
|     13+     | +4  |  Master  |

[Skilled Ability Check Modifier]

</div>

When making a check that involves a class skill, add the skill modifier for the PC's current level to the appropriate ability check roll.

-   ex: a 5th level thief that wants to use their Thief Skills to hide in the shadows would make a DEX ability check, rolling a d20 and adding their DEX modifier to the roll, and would _then_ add an additional +1 to the roll before determining the result.

### Complications

Complications can effect the immediate situation or the GM can optionally save them for later, tallying or counting them, and making a Complication Check for each one at the next appropriate time.

#### Complication Check

Roll 1d6.

<div class="dividedTableWrapper">

| 1d6 |      Result      |
| :-: | :--------------: |
|  1  |    Encounter     |
|  2  |     Locality     |
|  3  |    Exhaustion    |
|  4  | No complication  |
|  5  | Signs / Portents |
|  6  |    Discovery     |

[Complication Check Result]

</div>

-   **Encounter**: Wandering creature, social encounter, or some other random interaction.
-   **Locality**: Some environmental or external event that affects the PCs.
    -   ex: a storm rolls in, party gets lost, the dungeon shifts, water rises, the assassin gets closer to the target, doors lock behind party.
-   **Exhaustion**: Party must rest for a turn / watch or gain a level of [exhaustion](#exhausted).
    -   May be ignored for the first few checks in a session, as appropriate.
-   **Signs / Portents**: Indications of possible encounter nearby - could be a clue, monster tracks, etc.
-   **Discovery**: Party finds something useful or helpful.
    -   ex: a magic item, a secret door, a hidden ally.
    -   May be ignored after first occurrence in a session, as appropriate.

### Exploration Procedure

The time scales for exploration vary based on the area being explored:

-   Dungeon exploration is divided into 10-minute turns, with each turn covering roughly 180 feet of unexplored dungeon.
-   Wilderness exploration is divided into 4-hour watches, with each watch covering roughly 6 miles of unexplored (open) terrain.

The general steps to take when exploring (for each turn / watch):

1. **Setup**: GM describes the situation.
2. **Marching Order**: Party determines general exploration process, including direction of travel and speed.
3. [**Complication Check**](#complication-check): GM rolls the complication die to see what effect it has.
4. **Actions / Responses / Complications**: Party declares actions, GM describes the results (and any complications).
5. **End Turn / Watch**: When the party has gone far enough or combat has completed, the (dungeon) turn or (wilderness) watch ends.
6. **Repeat**: Return to step 2 and repeat until adventuring ends (or destination is reached).

### Challenges and Hazards

-   Fall damage is 1d6 per 10'.

#### Darkness

-   If unable to see, treat as [blinded](#blinded).
-   Candles light 10' radius.
-   Torches / lanterns light 30' radius.
-   When moving through darkness with flame light, no chance of stealth / surprise.

#### Infravision

Allows creatures to see heat tones, even in [darkness](#darkness).

-   Works to 60' unless noted otherwise.

#### Truesight

Allows creatures to:

-   see in normal or magical darkness;
-   see invisible creatures and objects;
-   automatically detect, see-through, and Save vs visual illusions;
-   perceive the true (original) form of a shapechanger or ploymorphed creature; and
-   see into the ethereal plane to perceive ghosts and other spirits.

#### Listening for Noises

Spend a minute listening (ex: at a door) and make an [INT or WIS check](#ability-checks) to hear a noise.

-   GM rolls.

#### Opening Doors

-   Locked Doors can be picked or broken.
    -   Picking a lock takes up to 1d6 minutes.
-   Stuck Doors can be unstuck or broken.
-   To unstick or break a door, make a [STR check](#ability-checks) at -2.
    -   Doors always break on a critical success.
    -   Failure / complications can affect stealth / surprise.

#### Swimming

-   Creatures are assumed to be able to swim at 1/2 their normal movement speed.
    -   Unless the creature is just floating, a [STR or CON check](#ability-checks) is required every turn (10 minutes).
        -   For creatures carrying heavy loads or wearing metal armor, this check is required very combat round (10 seconds).
        -   Failing this check results in a loss of 1 HP, and the check must be immediately attempted again.
        -   The third failure indicates the creature begins [drowning](#drowning).

##### Drowning

-   Each combat round, a drowning creature must **Save** or take 1d8 drowning damage.
-   When a drowning creature is rescued, it gains 1 level of exhaustion.
-   Once the exhaustion is cleared, the creature gains back any HP lost to drowning.

#### Urban Navigation

To navigate to a location in a busting city, make an **Urban Exploration Roll** (2d6 + [CHA mod](#ability-modifier-table) + [INT mod](#ability-modifier-table)).

-   Modify roll in friendly, dangerous, or especially alien areas.
-   Navigation time includes time spent reading maps and getting directions, as well as any eating or rest stops needed along the way.
-   Roll random encounter checks each hour.

<div class="dividedTableWrapper">

| Roll |  Result   |       Time Spent       |
| :--: | :-------: | :--------------------: |
|  2   |  Failure  |  Waste day searching   |
| 3-5  | Wandering | Arrive after 2d4 hours |
| 6-8  |  Success  | Arrive after 1d6 hours |
| 9-11 | Fortunate | Arrive after 1d4 hours |
| 12+  |  Direct   |  Arrive after 1 hour   |

[Urban Exploration Results]

</div>

#### Wilderness Exploration

-   Distances and non-magical ranges are tripled (yards rather than feet).
    -   Areas of breath weapons and spell effects are still measured in feet.

**Flight**

-   Unless stated otherwise, flight distance is double that of overland travel.
    -   Flight speed is not affected by terrain.
-   Winged beasts may be used as **mounts**, carrying riders or cargo based on the mount's HD:
    -   3 HD: May carry a creature 1/2 the size of a humanoid.
    -   6 HD: May carry a creature the size of a humanoid.
    -   12 HD: May carry a large creature (ex: horse)
    -   24 HD: May carry a huge creature (ex: elephant)

**Light**

-   During the daytime, fog or heavy rain will create dim light in open areas.
-   At night:
    -   A full moon on a clear night will create dim light in open areas.
    -   Fog or moonless night will create [darkness](#darkness).

<!--

**Foraging**

-   May be performed while traveling at normal pace.
-   Party has 1-in-6 chance of foraging enough for 1d6 characters

**Hunting**

-   Takes a complete day (no travel or resting possible).
-   Party has 1-in-6 chance of encountering game.
    -   This is in addition to normal random encounter chances.


**Losing Direction**

-   At the start of each day, GM should roll to determine if group loses direction.
-   Chance of losing direction depends on terrain being traversed:
    -   Grasslands, plains, clear: 1-in-6
    -   Hills, mountains, woods, barren areas: 2-in-6
    -   Swamp, jungle, desert: 3-in-6

-->

**Overland Travel**

-   The distance in miles that a character can travel overland in a day (16 hours) under normal conditions (and clear terrain) can be determined by multiplying their base movement rate by .6 (or 3/5).

    -   10' / round => 6 miles / day
    -   20' / round => 12 miles / day
    -   30' / round => 18 miles / day
    -   40' / round = 24 miles / day

-   Some terrain affects overland speed while traveling through it:

    -   Maintained roads: Increase speed by 50%.
    -   Hilly, wooded, or desert terrain: Decrease speed by 33%.
    -   Swampy, mountainous, or jungle terrain: Decrease speed by 50%.

-   Characters engaged in a forced march can increase their travel speed by 50%, but must rest for a full day or suffer 2 levels of [exhaustion](#exhausted).

-   Characters can travel for up to 6 days before they must rest for at least 1 full day.
    -   For each day beyond the 6th that they travel without resting, they gain a level of exhaustion.

**Sight**

Characters can usually see 3 miles around (in clear terrain).

-   Range of sight may vary based on terrain (ex: less in wooded area, more on an overlook).

### Encounter Procedure

1. **Check Stealth**: GM rolls for stealth, if applicable.

    - Each side that's being relatively stealthy (quiet, douses torches, etc.) has a base 2-in-6 chance of not being spotted.
        - Parties carrying an active light source typically can not have stealth.
        - Individual party members may have stealth even if the rest of the party doesn't.
    - If only one side has stealth, they may usually make a free attack (or can pass unnoticed).
    - If all sides have stealth, they miss each other.

2. **Determine Distance**: GM determines how far away the characters are from the encounter.

    - Often determined by the nature of the encounter itself, but may be determined randomly:
        - Dungeon: 2d6 x 10'
        - Wilderness: 4d6 x 10 yards (or 1d4 x 10 yards if either side is surprised).

3. **Roll Initiative**: Each side rolls 1d20, highest roll moves first.

    - Tie goes to the party side, roll-off as needed.

4. **Choose Actions**: Each side decides how they will respond in initiative order, and the encounter proceeds.
    - Players decide how their characters will act.
    - Creature actions are often determined by the nature of the encoulastnter itself, but may be determined randomly.
        - If creature / NPC reaction isn't obvious, make a **Reaction Roll** (2d6, possibly modified based on what the creature / NPC believes about the party beforehand).
        - If someone tries to communicate, make a 2nd reaction roll, this time modified by the speaker's [CHA modifier](#ability-modifier-table) and a modifier based on the first roll as indicated below.

<div class="dividedTableWrapper" id="reaction-table">

| 2d6 |   Result    | 2nd Roll Mod |
| :-: | :---------: | :----------: |
| 2-  |   Attack!   |      -3      |
|  3  |   Hateful   |      -2      |
|  4  |    Leery    |      -1      |
|  5  |    Rude     |      -1      |
|  6  |    Aloof    |      0       |
|  7  |  Uncertain  |      0       |
|  8  |  Confused   |      0       |
|  9  | Indifferent |      +1      |
| 10  |   Cordial   |      +1      |
| 11  |   Amiable   |      +2      |
| 12+ |  Friendly!  |      +3      |

[Reaction Table]

</div>

5. **End Turn**: Once the encounter has played out, the turn ends.

-   Each encounter is assumed to take at least one full turn to complete.
    -   This includes time to regroup, bind wounds, clean weapons, etc.

#### Typical Actions

While any action is possible, the following actions are the most common:

-   **Combat**: If a side attacks, casts a spell, or makes a tactical movement, [combat](./combat.html) begins.
-   **Evasion**: If a side decides to flee, another side may decide to pursue.
-   **Talk**: One side may attempt to communicate with the other(s).

#### Evasion

Any side that wishes to avoid an encounter may attempt to flee.

-   Only possible before combat begins.
-   Each opposing side declares whether or not they want to pursue.
    -   Players decide freely if they wish to pursue fleeing creatures.
    -   GM decides whether creatures pursue fleeing PCs (based on circumstances or roll).
-   If all opposing sides decide not to pursue, the evasion attempt automatically succeeds and the encounter is avoided.
-   If an opposing side decides to pursue, the chance of evading depends on the surrounding environment.

### Advancement

As the adventures continue, the PCs will interact with their world, gaining Level Points for each session.

-   Once a PC acquires a number of Level Points equal to their next desired level, they may gain a level in their desired class.

#### Upon Gaining a Level

When a PC increases their level, the following actions may be performed:

-   Roll a hit die (based on the class), and add it to their maximum hit points.
    -   1s and 2s may be re-rolled a single time.
-   Check the [Skilled Ability Check Modifier table](#skilled-ability-checks) to determine if their skill modifier increases.
-   Check the PC's [class](/classes/) and [race](/races/) to see if they gain any new.
-   The player may pick one of the PC's abilities, and roll 3d6.
    -   If the resulting roll is higher than the ability score, increase the score by 1.

### Creature Conditions

#### Blinded

-   A blinded creature:
    -   can’t see,
    -   automatically fails any ability check that requires sight, and
    -   only hits on a natural 20 (as a critical hit).
-   +4 to attacks against a blinded creature.

#### Deafened

-   A deafened creature:
    -   can’t hear, and
    -   automatically fails any ability check that requires hearing.
-   +2 to attacks against a deafened creature.

#### Entangled

-   An entangled creature:
    -   is unable to move,
    -   has [disadvantage](./basics.html#advantage-and-disadvantage) on attack rolls and ability checks that require moving,
    -   can make a new **Save** attempt each combat round,
    -   is automatically released if the entangling weapon is used to attack another opponent.
-   Attack rolls against an entangled creature have [advantage](./basics.html#advantage-and-disadvantage).

#### Exhausted

-   An exhausted creature:
    -   gets -1 to _all_ rolls, and
    -   has their AC reduced by 1.
    -   These effects are cumulative for each level of exhaustion they have.
-   Each level of exhaustion can be cleared by resting for 4 hours (1 watch).
-   Going for more than one day with a long rest adds 1 level of exhaustion per day since last long rest.

#### Frightened

-   A frightened creature:
    -   is unable to willingly move closer to the source of its fear (desiring only to flee from it), and
    -   has disadvantage on ability checks and attack rolls while it can see the source of its fear.
-   Most unintelligent creatures will actively flee when frightened.

#### Invisible

-   An invisible creature:
    -   can't be seen without magic or a special sense (ex: [Truesight](#truesight)),
    -   can only be tracked by any noise it makes or tracks it leaves, and
    -   gets advantage on attacks.
-   Attacks against an invisible creature have disadvantage and can only be made when attacking creature has _some_ idea of where the invisible creature is (or recently was).

#### Paralyzed

-   A paralyzed creature:
    -   is unable to speak, move, attack, or take any actions; and
    -   automatically fails any ability check that requires movement or speech.
-   Attack rolls against a paralyzed creature have advantage.
    -   If the attacker is within 5 feet, any attack that hits is a [critical hit](./combat.html#critical-hits).
    -   Optionally, the GM may rule that a paralyzed creature can be instantly killed (ex: slitting its throat).

#### Petrified

-   A petrified creature:
    -   is transformed, along with any nonmagical object it is wearing or carrying, into a solid inanimate substance (usually stone);
    -   is unable to speak, move, attack, or take any actions;
    -   automatically fails any ability check that requires movement or speech;
    -   ceases to age;
    -   weighs 10x their normal weight;
    -   only takes 1/2 damage from everything except explosives and pick-type weapons; and
    -   is immune to poison and disease (although a poison or disease already in its system is suspended, not neutralized).
-   Attack rolls against a petrified creature have advantage.
    -   When attacked and the attacker fumbles, their weapon breaks.

#### Poisoned

A poisoned creature has disadvantage on attack rolls and ability checks.

#### Prone

-   A prone creature:
    -   moves at half normal speed,
    -   can stand up for half its normal speed (ending the condition), and
    -   has disadvantage on attack rolls.
-   When attacking a prone creature:
    -   melee attacks have advantage, and
    -   ranged attacks have disadvantage.

#### Restrained

-   A restrained creature:
    -   is unable to move, and
    -   has disadvantage on attack rolls and ability checks that require moving.
-   Attack rolls against a restrained creature have advantage.

#### Stunned

-   A stunned creature:
    -   is unable to move, attack, take any actions, and can speak only falteringly; and
    -   automatically fails any ability check that requires movement.
-   Attack rolls against an stunned creature have advantage.

#### Unconscious

-   An unconscious creature:
    -   is unable to speak, move, attack, or take any actions;
    -   automatically fails any ability check that requires movement or speech; and
    -   is unaware of their surroundings.
-   When a creature is rendered unconscious, they drop whatever they are holding and fall prone.
-   Attack rolls against an unconscious creature have advantage.
    -   If the attacker is within 5 feet, any attack that hits is a [critical hit](./combat.html#critical-hits).
    -   Optionally, the GM may rule that a paralyzed creature can be instantly killed (ex: slitting its throat).

### Encumbrance

Characters can carry a number of "Important Items", based on their Strength (STR).

-   Items can be carried **At Ready** or **Packed**.
    -   "At Ready" items may be grabbed and used without delay.
    -   Packing or unpacking items takes 1 turn.
-   Characters can carry a number of at-ready items up to their Strength (STR), with a minimum of 7.
    -   Additionally, characters may carry a number of packed items up to their Strength (STR), also with a minimum of 7.
-   Leather armor (with or without studs) counts as 1 item, chain mail and half plate each count as 2 items, and full plate counts as 3 items.
-   2-handed weapons count as 2 items.
-   100 coins or gems count as 1 item.
-   Carrying more ready or packed items than allowed can be done, but movement is halved (or worse).
    -   Carrying more than twice the allowed number of ready or packed items reduces movement to 0.

### Health, Damage and Dying

The state of a character's health is determined by their number of hit points (HP).

-   Starting HP is usually determined by class and level.
    -   The type of Hit Dice to throw is determined by class
    -   The number of Hit Dice to throw is determined by level.
    -   Re-roll any 1s or 2s.
    -   Modify the rolled value of each die by CON as below:

<div class="dividedTableWrapper" id="constitution-modifier">

|  CON  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

[Constitution Modifier]

</div>

-   When damage is taken, HP is lost.

#### Dying

-   Creatures and NPCs usually die at 0 HP.
-   When a PC drops below 0 HP, they are momentarily [stunned](#stunned) until they **Save** at the end of their next initiative turn.
    -   The Saving throw is modified as follows:
        -   the PC's CON modifier is applied to it,
        -   -1 for each HP bellow 0, and
        -   +1/2 current level (round up).
    -   On a success, the PC stabilizes at 0 HP.
    -   On a fail, the PC can give some potential final words before falling [unconscious](#unconscious), apparently dead.
-   While a PC is stabilized at 0 HP, they:
    -   can only move 1/2 their normal rate,
    -   can't attack or cast spells, and
    -   can make an INT check and try to restore their mobility.
        -   The check counts as a combat action.
        -   On a full success, the PC heals to 1 HP and can move and attack as normal.
        -   On a complicated success, the PC remains at 0 HP.
        -   On a failure, the PC drops to -1 HP and is momentarily [stunned](#stunned) until they **Save** at the end of their next initiative turn.
-   Any _other_ character may make an [INT check](#ability-checks) to try and help a stabilized or stunned PC at or below 0 HP, restoring their mobility.
    -   The check counts as a combat action.
    -   On a success, the PC heals to 1 HP and can move and attack as normal.
    -   On a normal failure, the PC remains at current HP.
    -   On a critical failure, the PC loses 1 HP and is momentarily [stunned](#stunned) until they **Save** at the end of their next initiative turn.

##### Recovering the Body

If the body of an apparently dead PC is recovered, the PC gets one final chance to **Save** or Die.

-   Add CON modifier to roll,
-   On a success, the PC sits upright wheezing deeply, having only been winded or wounded, and is restored to 1 HP (able to move and attack as normal).
-   On a failure, the PC is well and truly dead - there's nothing to do but go through their pockets for loose change.

<!--

Spirits!

-->

#### Healing

-   After each long rest (8+ hours of sleep), regain 1 _hit die (HD)_ worth of HP.
-   Once per day, take a short rest (10 minutes) and eat a ration to regain 1 HD worth of HP.
-   Drinking certain potions can restore HP:
    -   A potion of healing restores up to 1d6+1 HP.
    -   A potion of greater healing restores up to 2d6+2 HP.
    -   A potion of supreme healing restores up to 3d8+3 HP.
-   Quaffing a readied potion takes a combat action, but can be done while moving.

<!--
### Knowledge

-   Spellcasters may make an INT check to identify a magic item.
    -   Failures cannot be re-attempted until research is performed or a level is gained.
-->

### Languages

-   Anyone who speaks a language can understand other related languages (ex: dialects) with a successful INT check.
-   Some orders and guilds (especially those that engage in illegal / immoral acts) may teach their members secret or otherwise coded language.
-   The following lists of languages are not all-inclusive.

#### Alignment Languages

Assumed to shared by all (intelligent) members of a given alignment.

-   **Chaotic**: Alignment language of chaos.
-   **Lawful**: Alignment language of law.
-   **Neutral**: Alignment language of neutrality.

#### Class Languages

Most class languages are secret, known only to members of their class, and often include coded terms and/or physical motions (hand waves, knocks, etc.).

-   **Assassin's Cant**: Secret (and coded) language known to all thieves.
    -   Dialects are based on different guilds.
-   **Corsair's Cant**: Secret (and coded) language spoken by all Corsairs.
    -   Dialects are based on different ship / locations.
-   **Druidic**: Secret language spoken by all Druids.
-   **Thieves' Cant**: Secret (and coded) language known to all thieves.
    -   Dialects are based on different guilds.

#### Racial Languages

-   **Aerian**: Native language of air elementals, dialect of elemental.
-   **Angelic**: Native language of angels (law elements), dialect of both lawful and elemental.
-   **Aquon**: Native language of water elementals, dialect of elemental.
-   **Chitter**: The secret language of burrowing mammals, known to many gnomes.
-   **Demonic**: Native language of demons (chaos elements), dialect of both chaotic and elemental.
-   **Doppleganger**: Native language of dopplegangers.
-   **Draconic**: Native language of most intelligent reptilian races (kobolds, troglodytes, lizardfolk, dragons, dracokin, etc.).
-   **Duncommon**: Native language of those that dwell deep underground and other dark places (Drow, Medusa, etc.).
-   **Dwarfish**: Native language of dwarves.
-   **Elemental**: Spoken by all elementals, each subtype has their own dialect.
-   **Elvish**: Native language of elves, dialect of faerie.
-   **Faerie**: Native language of the fae, usually divided into 2 dialects:
    -   **High Faerie** Spoken in the ruling courts of the Faewolde.
    -   **Low Faerie**: Spoken everywhere outside of the ruling courts of the Faewolde.
-   **Farspeak**: Language of the far realms.
-   **Firbish**: Native language of firbolgs.
-   **Giant**: Native language of giants.
-   **Goblinoid**: Native language of most intelligent goblinoid races (boggarts, bugbears, goblins, hobgoblins, etc.)
-   **Gnollish**: Native language of gnolls and jakkra.
-   **Gnomish**: Native language of gnomes.
-   **Greyok**: Native language of several intelligent mammalian animalkin races (Elekin, Hippokin, Rhinokin, Taurokin).
-   **Halfling**: Native language of halflings.
-   **Orcish**: Native language of ogres and orcs.
-   **Pyrean**: Native language of fire elementals, dialect of elemental.
-   **Strallan**: Native language of the Stral and official language of the Stral Empire.
-   **Terrun**: Native language of earth elementals, dialect of elemental.

<div class="dividedTableWrapper">

|  INT  | Spoken Languages | Read? |
| :---: | :--------------: | :---: |
|   3   | Native (broken)  |  No   |
|  4-5  |      Native      |  No   |
|  6-8  |      Native      | Basic |
| 9-12  |      Native      |  Yes  |
| 13-15 |    Native + 1    |  Yes  |
| 16-17 |    Native + 2    |  Yes  |
|  18+  |    Native + 3    |  Yes  |

[Languages Known]

</div>

### Perception Checks

Generally, perception can be checked by making either an [INT or WIS check](#ability-checks).

### Size

A creature's size is usually defined by one of the following categories based on its height and/or weight:

<div class="dividedTableWrapper">

|    Size    | Max Height |  Max Weight  | Control Radius |
| :--------: | :--------: | :----------: | :------------: |
| Diminutive |     1'     |     1 lb     |       1'       |
|    Tiny    |     2'     |    8 lbs     |      2.5'      |
|   Small    |     4'     |    60 lbs    |       5'       |
|   Medium   |     8'     |   500 lbs    |       5'       |
|   Large    |    16'     |   4000 lbs   |      10'       |
|    Huge    |    32'     |  32,000 lbs  |      15'       |
| Gargantuan |    64'     | 250,000 lbs  |      20'       |
|  Colossal  |    65'+    | 250,001+ lbs |      30'       |

[Creature Sizes]

</div>

### Time

Time is often represented at different scales:

-   A combat round is 10 seconds long.
-   An exploration turn takes 10 minutes.
-   A watch takes 4 hours.
-   A long rest takes 8 hours.

<!--
### Usage Die

Some equipment (including many magic items) have limited uses, tracked via a **Usage Die**.

-   The item description will indicate the starting die type.
-   After each use, roll the current die, and on a 1-2, the die drops one step (d20 -> d12 -> d10 -> d8 -> d6 -> d4 -> 1) as uses are consumed.
    -   After dropping a die step from a d4, the magic item has only 1 use remaining.
-   When no more uses are left, the item becomes inert.
-   At the GM's discretion, it may be possible to recharge some magic items, increasing the usage die via complex magic rituals.
-->

!!!include(license/wotc-cc-by.md)!!!
