---
title: 'HOSR Core Rules: Combat'
description: The rules for running combat in HOSR.
date_pub: 2023-04-22T16:42:00-04:00
section: rules
content_type: feature
short_code: uhc
---

[[toc]]

### Combat Procedure

Adventurers tend to die easily, so most combat should be avoided unless the adventurers have a clear [advantage](/rules/basics.html#advantage-and-disadvantage).

That having been said, fights do occur, and when they do, the following steps are performed:

1. **Declare Spells, Special Attacks, Defending, and Retreats**: Players declare if they will _cast a spell_, _use a special attack_, _defend_, or _retreat_ this round (and, if so, which type of retreat).
2. **Roll Initiative**: Each side that can attack rolls 1d20, highest roll attacks first.
    - Tie goes to the party side.
3. **Winning Side Actions**: Each character or monster gets a move and an action, with either one occurring first.

    - **Morale Check**: Creatures who've been severely wounded or seen their leaders killed may flee.

        - Roll 2d6 under morale score or the monsters surrender / flee.
            - After 2 successes in a fight, no further checks required.
        - When to check morale:
            - After the first death on a side, and
            - When a side is half killed or incapacitated.

    - **Move**: Move up to full speed
        - If prone, use 1/2 movement to stand up.
        - If _engaged_ with an enemy at the start of the move, must make a _fighting retreat_ or enemy gets free attack.
        - If moving before an attack, up to 10' of movement can be "saved" to use after the attack finishes.
    - **Action**: Do something, like _attack_, _defend_, _cast a spell_, or stowe an item.
        - Spellcasters can move _before_ casting a spell, but can't move _after_ casting one.

4. **Change Sides**: Opposing side becomes active.
    - If more than 2 sides are fighting, the side with the next highest initiative roll becomes active.
5. **Slow Weapons**: Resolve any slow weapons or end-of-round abilities.
6. **Repeat**: Return to step 2 and repeat until only one side remains.

### Readying Weapons

-   Available weapons may be readied for free while moving (if hands are empty or currently held items are dropped).
-   Stowing held weapons takes a full action.

### Attacking

Roll 1d20 plus any appropriate modifiers. If it equals or beats the target's AC, roll for damage (again including any appropriate modifiers).

-   +2 bonus to hit from behind (if victim is unaware).
-   When mounted, +1 bonus to hit most foes on foot.

#### AC

-   Character AC is usually determined by type of **armor** worn.
-   **Shields** grant +1 AC when used.
    -   Can also be sacrificed (shattered) to prevent a hit from inflicting damage.

##### Fantasy Armor

<div class="dividedTableWrapper">

|   Armor Type    | AC  |
| :-------------: | :-: |
|      None       | 10  |
|  Padded / Hide  | 11  |
|     Leather     | 12  |
| Studded Leather | 13  |
|    Chainmail    | 14  |
|   Half-Plate    | 15  |
|   Full Plate    | 16  |

[Fantasy Armor AC]

</div>

##### Modern Armor

<div class="dividedTableWrapper">

|     Armor Type      | AC  |
| :-----------------: | :-: |
|        None         | 10  |
|        Weave        | 11  |
|  Leather / Textile  | 12  |
|   Light Body Vest   | 13  |
|   Heavy Body Vest   | 14  |
|  Armored Longcoat   | 15  |
| Tactical Body Armor | 16  |
| Military Body Armor | 17  |

[Modern Armor AC]

</div>

#### Holding Attacks

Rather than attacking, characters can move into position and hold attacks until a specific trigger occurs (ex: covering a door and only attacking if someone comes through).

-   If the trigger occurs before the character's side gets initiative again, they may make a single free attack.

#### Melee Attacks

Melee attack rolls are modified based on the character's Strength.

<div class="dividedTableWrapper">

|  STR  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

[Strength Modifier]

</div>

-   Melee attacks are usually limited to 5' range.
-   Characters in melee combat with each other or other monsters are said to be **engaged**.
-   Unarmed attacks do 1d2 damage by default.

##### Dual Wielding

PCs with DEX 13+ can dual wield certain weapons.

-   When using 2 Light weapons, may make an attack with each one.
-   When using a one-handed weapon and a Light weapon, may only make one attack, but +1 to the attack and damage rolls.

#### Ranged Attacks

Ranged attack rolls are modified based on the character's Dexterity, the target's cover, and the range to the target.

<div class="dividedTableWrapper">

|  DEX  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

[Dexterity Modifier]

</div>

-   -1 to -4 penalties may apply when attacking targets behind partial cover.
    -   Targets behind total cover cannot be hit.
-   Ranged attacks within 5' are made with [disadvantage](./basics.html#advantage-and-disadvantage).
-   Attacks beyond long range are not possible.

<div class="dividedTableWrapper">

| Range  | Mod |
| :----: | :-: |
| Short  | +1  |
| Medium | --  |
|  Long  | -1  |

[Range Modifier]

</div>

#### Critical Hits

A natural 20 on an attack is a critical hit. Roll 1d20 on the Critical Hit Table to see what additional effect occurs.

<div class="dividedTableWrapper">

| 1d20 |               Effect               |
| :--: | :--------------------------------: |
| 1-2  |             Max Damage             |
|  3   |    Max Damage + Free Attack[^1]    |
|  4   |   Max Damage + Target Fumble[^2]   |
|  5   |  Max Damage + Target Blinded[^3]   |
|  6   |           Double Damage            |
|  7   |  Double Damage + Free Attack[^1]   |
|  8   | Double Damage + Target Fumble[^2]  |
|  9   | Double Damage + Target Blinded[^3] |
|  10  |         Double Max Damage          |
|  11  |           Triple Damage            |
|  12  |  Triple Damage + Free Attack[^1]   |
|  13  | Triple Damage + Target Fumble[^2]  |
|  14  | Triple Damage + Target Blinded[^3] |
|  15  |         Triple Max Damage          |
|  16  |        Quadruple Max Damage        |
|  17  |   Max Damage + Armor Damaged[^4]   |
|  18  | Max Damage + Target Amputation[^5] |
|  19  |  Max Damage + Target Stunned[^6]   |
|  20  |       Save vs. Death or die        |

[Critical Hit Table]

[^1]: **Free Attack**: Attempt another hit with same weapon
[^2]: **Target Fumble**: Target must roll on fumble table
[^3]: **Target Blinded**: Blood or debris renders target [blinded](./adventuring.html#blinded) for 1d4 rounds
[^4]: **Armor Damaged**: Reduce target's AC by 1 until armor repaired / healed
[^5]: **Target Amputation**: Target loses an appendage.
[^6]: **Target Stunned**: Blow stuns target for 1d6 rounds

</div>

#### Fumbles

A natural 1 on an attack is a fumble. Roll 1d20 on the Fumble Table to see what additional effect occurs.

<div class="dividedTableWrapper">

| 1d20 |                         Effect                         |
| :--: | :----------------------------------------------------: |
|  1   |                 Stumble, weapon breaks                 |
|  2   | Stumble, automatic hit on closest ally within 10'[^1]  |
|  3   | Stumble, next attack against is automatic critical hit |
|  4   |     Stumble, can't attacks until end of next round     |
|  5   |         Stumble, can't attack until next round         |
|  6   |     Stumble, next attack against is automatic hit      |
|  7   |        Stumble, hit self for maximum damage[^1]        |
|  8   |        Stumble, hit self for regular damage[^1]        |
|  9   |          Stumble, all rolls next round get -2          |
|  10  |       Stumble, go last in initiative next round        |
|  11  |       Fall down (prone) and drop weapon 30' away       |
|  12  |       Fall down (prone) and drop weapon 20' away       |
|  13  |       Fall down (prone) and drop weapon 10' away       |
|  14  |        Fall down (prone) and drop weapon nearby        |
|  15  |                   Fall down (prone)                    |
|  16  |                  Drop weapon 30' away                  |
|  17  |                  Drop weapon 20' away                  |
|  18  |                  Drop weapon 10' away                  |
|  19  |                  Drop weapon at feet                   |
|  20  |            Fumble weapon, but maintain hold            |

[Fumble Table]

[^1]: **Automatic Hits**: Roll 1d20 to check for critical, but ignore further fumbles.

</div>

### Defending

Spend a round fighting defensively (parrying, blocking, dodging, feinting, etc.). Gets +2 AC. Can be used with **Fighting Retreat**.

### Movement

Most characters can move 40' in a combat round.

-   **When Engaged**: Can't move away from foe without retreating.
-   **When Prone**: Use 1/2 movement to stand up.

### Retreating

Engaged characters that wish to move away can either make a fighting retreat, or a full retreat.

-   **Fighting Retreat**: Can move backwards at 1/2 their normal movement rate and take an attack or defend action, while avoiding giving enemies a free attack.
-   **Full Retreat**: Turning and fleeing from combat at their full movement rate, enemies can make a free attack at +2 bonus.

### Weapons

-   One-handed weapons are weapons that may be wielded with one hand (ex: no weapons with "Two-handed", but includes weapons with "Versatile").

#### Melee Weapons

<div class="dividedTableWrapper">

|       Weapon       | Damage |           [Properties](#weapon-properties)            |
| :----------------: | :----: | :---------------------------------------------------: |
|     Battle Axe     |  1d8   |                   Versatile (1d10)                    |
|     Blackjack      |  1d2   |                    Blunt, Stealth                     |
|     Chain Whip     |  1d6   |                    Entangle, Reach                    |
| Chain Whip, Spiked |  1d8   |                    Entangle, Reach                    |
|        Club        |  1d4   |                     Blunt, Light                      |
|       Dagger       |  1d4   |            Light, Thrown (10' / 20' / 30')            |
|       Flail        |  1d6   |                                                       |
|      Garotte       |  1d4   |             Entangle, Stealth, Two-handed             |
|     Greatclub      |  1d8   |                   Blunt, Two-handed                   |
|     Greatsword     |  1d12  |                   Slow, Two-handed                    |
|      Hand Axe      |  1d4   |            Light, Thrown (10' / 20' / 30')            |
|      Javelin       |  1d6   |                Thrown (30'/ 60' / 90')                |
|       Katana       |  1d10  |             Two-handed, Versatile (1d12)              |
|      Lajatang      |  2d4   |             Two-handed, Versatile (1d12)              |
|       Lance        |  1d6   |                        Charge                         |
|    Light Hammer    |  1d4   |        Blunt, Light, Thrown (10' / 20' / 30')         |
|     Longsword      |  1d8   |                   Versatile (1d10)                    |
|        Mace        |  1d6   |                         Blunt                         |
|    Morningstar     |  1d8   |                                                       |
|        Net         |   0    | Blunt, Entangle, Thrown (10' / 20' / 30'), Two-handed |
|      Nunchaku      |  2d4   |                   Blunt, Two-handed                   |
|      Pickaxe       |  1d8   |                   Slow, Two-handed                    |
|      Polearm       |  1d10  |                Reach, Slow, Two-handed                |
|       Rapier       |  1d8   |                                                       |
|      Scimitar      |  1d6   |               Thrown (10' / 20' / 30')                |
|       Sickle       |  1d4   |                         Light                         |
|     Shortsword     |  1d6   |                                                       |
|       Spear        |  1d6   |      Thrown (20' / 40' / 60') , Versatile (1d8)       |
|    Spiked Chain    |  1d4   |         Entangle, Two-handed, Versatile (1d6)         |
|       Staff        |  1d4   |                Blunt, Versatile (1d6)                 |
|      Trident       |  1d6   |      Thrown (10' / 20' / 30') , Versatile (1d8)       |
|     Warhammer      |  1d6   |                Blunt, Versatile (1d8)                 |
|        Whip        |  1d4   |                    Entangle, Reach                    |

[Melee Weapons]

</div>

##### Melee Weapon Details

-   **Blackjack**: On successful hit, target must **Save vs Paralyze** or be knocked unconscious for 1d6 turns.
-   **Garotte**: While target is entangled, inflicts damage automatically each round, can be used for [Sneak Attack](/classes/thief.html#core-features).
-   **Net**: Big enough for 6' humanoid creature, larger nets may require more handlers.
-   **Polearm**: Includes any weapon with a long pole tipped with a cutting / spearing weapon (ex: Glaive, Halberd, Pike).
-   **Whip**: On a successful hit, may either inflict damage OR entangle.

#### Traditional Ranged Weapons

<div class="dividedTableWrapper">

|     Weapon      | Damage |       Range       |             [Properties](#weapon-properties)             |
| :-------------: | :----: | :---------------: | :------------------------------------------------------: |
|     Blowgun     |   1    | 25' / 50' / 100'  |            Ammunition (Blowdart), Reload (1)             |
|      Bolas      |  1d2   |  20' / 40' / 60'  |                     Blunt, Entangle                      |
| Crossbow, Hand  |  1d4   |  20' / 40' / 80'  |      Ammunition (Crossbow bolt), Light, Reload (1)       |
| Crossbow, Heavy |  1d8   | 80' / 160' / 240' | Ammunition (Crossbow bolt), Reload (1), Slow, Two-handed |
| Crossbow, Light |  1d6   | 40' / 80' / 120'  |    Ammunition (Crossbow bolt), Reload (1), Two-handed    |
|    Great Bow    |  1d8   | 70' / 140' / 210' |           Ammunition (Arrow), Slow, Two-handed           |
|     Longbow     |  1d6   | 70' / 140' / 210' |              Ammunition (Arrow), Two-handed              |
|    Shortbow     |  1d6   | 50' / 100' / 150' |              Ammunition (Arrow), Two-handed              |
|      Sling      |  1d4   | 40' / 80' / 160'  |           Ammunition (Stone or Bullet), Blunt            |

[Traditional Ranged Weapons]

</div>

##### Traditional Ranged Weapon Details

-   **Sling**: Typically uses stones, bullets add +1 damage (1d4+1 total).

#### Firearms

<div class="dividedTableWrapper">

|      Weapon      | Damage |       Range        |                    [Properties](#weapon-properties)                     |
| :--------------: | :----: | :----------------: | :---------------------------------------------------------------------: |
| Grenade Launcher |  4d6   |  40' / 80' / 120'  |          Ammunition (Grenade), Reload (1), Special, Two-Handed          |
|   Machine Gun    |  2d12  | 125' / 250' / 375' | Ammunition (Rifle cartridge), Mounted, Reload (30), Spread, Two-Handed  |
|     Needler      | 2d6+1  | 50' / 100' / 150'  |                Ammunition (Needles), Reload (30), Spread                |
|  Pistol, Light   |  2d3   | 50' / 100' / 150'  |      Ammunition (Handgun cartridge), Concealed, Light, Reload (2)       |
|      Pistol      |  2d4   | 50' / 100' / 150'  |           Ammunition (Handgun cartridge), Light, Reload (15)            |
|     Revolver     | 2d4+1  | 50' / 100' / 150'  |               Ammunition (Handgun cartridge), Reload (6)                |
|  Rifle, Assault  |  2d8   | 100' / 200' / 300' |      Ammunition (Rifle cartridge), Reload (30), Spread, Two-handed      |
|  Rifle, Hunting  |  2d8   | 150' / 300' / 450' |        Aim, Ammunition (Rifle cartridge), Reload (6), Two-handed        |
|  Rifle, Sniper   |  2d10  | 200' / 400' / 600' |        Aim, Ammunition (Rifle cartridge), Reload (1), Two-handed        |
|     Shotgun      |  2d8   | 50' / 100' / 150'  | Ammunition (Shotgun shell), Point Blank, Reload (6), Spread, Two-handed |
| Sub-Machine Gun  |  2d6   | 50' / 100' / 150'  |           Ammunition (Handgun cartridge), Reload (30), Spread           |
| Rocket Launcher  |  5d6   | 100' / 200' / 300' |               Ammunition (Rocket), Reload (1), Two-Handed               |

[Firearms]

</div>

##### Firearms Details

-   **Grenade Launcher**: Rather than attacking, pick target point up to 120' away and use an action to make a DEX skill check. On a success, the grenade hits that spot. On a fail, roll 1d8 to determine which direction the grenade landed (relative to the target, starting from directly in front of them and moving clockwise), and 1d6 to determine how far away (multiply by 5').
-   **Rocket Launcher**: On a miss, starting with the nearest creature to the target, each creature directly behind the target (relative to the launcher's wielder, but still within range of the rocket launcher) must Save or be inadvertently hit by the rocket. If everyone avoids the rocket but it was fired in an enclosed space, it strikes the nearest wall instead.

<!--
##### Ammunition

**Grenades**

See [explosives](#explosives).

**Handgun Cartridge**

-   Armor Piercing
-   Hollow Point

**Rifle Cartridge**

-   Armor Piercing
-   Hollow Point

**Shotgun Shell**

-   Dragonfire
-   Slug
-   Spread
-->

#### Weapon Properties

!!!include(rules/weapon-properties.md)!!!

#### Explosives

Most lobbed explosives (bombs, dynamite, grenades, etc.) work the same way:

-   Wielder picks a target spot within 60' and uses a combat action to make a DEX check.
    -   On a success, the explosive lands in the spot and explodes as expected.
    -   On a fail, determine where the explosive landed.
        -   Roll 1d8 to determine which direction from the intended target it went (relative to the thrower, starting from directly in front of them and moving clockwise).
        -   Roll 1d6 and multiply the result by 5' to determine how far away from the target spot the explosive landed.

##### Bombs

-   Can be lit and thrown as above.
-   When detonated, causes 3d6 damage to all creatures within 5' (**Save** for half-damage).
-   Can be found throughout the multiverse.

##### Dynamite

-   Can be lit and thrown as above.
-   When detonated, a single stick causes 3d6 damage to all creatures within 5' (**Save** for half-damage).
-   Sticks may be bound together to increase explosive power.
    -   Damage increases by 1d6 per stick beyond the first, up to 10d6.
    -   Blast radius increases by 5' per stick beyond the first, up to 20'.
-   Fuses can be extended so the detonation occurs after a specific amount of time (ex: after 6 rounds).
    -   At the end of each round, decrease the remaining time by 1.
    -   When the timer reaches 0, the detonation occurs.
-   Can only be found on industrialized planes.

##### Grenades

-   Can either be thrown as or launched from a grenade launcher (extending range to 120').
-   Types of Grenades
    -   Fragmentation: Detonates on impact sending shrapnel in all directions.
        -   All creatures within 20' of where the grenade landed take 4d6 damage, **Save** for half-damage.
    -   Poison Gas: One combat round after the grenade lands, it creates a cloud of deadly gas around it.
        -   All creatures within 20' of where the grenade landed must **Save** or die.
        -   Gas remains for an additional 10 seconds (1 combat round), so that any creatures in the affected area at the end of the following combat round must **Save** or or die (even if they already saved once).
    -   Sleeping Gas: One combat round after the grenade lands, it creates a cloud of sleep-inducing gas.
        -   All creatures within 20' of where the grenade landed must **Save** or fall asleep for 2d4 turns.
        -   Gas remains for an additional 10 seconds (1 combat round), so that any creatures in the affected area at the end of the following combat round must **Save** or fall asleep for 2d4 turns (even if they already saved once).
    -   Smoke: One combat round after the grenade lands, it creates a thick cloud of smoke.
        -   Heavily obscures the area within 20' of where the grenade landed.
        -   Lingers for 1 minute (6 combat rounds) unless blown away.
            -   A moderate wind (at least 10 mph) clears area in 3 rounds.
            -   A strong wind (at least 20 mph) clears area in 1 round.
-   Can only be found on industrialized planes.

##### Gunpowder

-   When lit on fire, instantly detonates.
    -   An exploding ounce of gunpowder flares for 1 combat round, casting bright in a 30' radius and dim light for an additional 30'.
    -   An exploding powder horn causes 3d6 damage to all creatures within 10' (**Save** for half-damage).
    -   An exploding powder keg causes 6d6 damage to all creatures within 20' (**Save** for half-damage).
-   Can be found throughout the multiverse.

!!!include(license/wotc-cc-by.md)!!!
