---
title: 'HOSR Core Rules: Magic'
description:
date_pub: 2023-04-22T16:42:00-04:00
section: rules
content_type: feature
short_code: uhm
---

[[toc]]

### Magic & Spells

Spells are patterns of energy that can be manipulated and used by some characters to alter reality to their will.

When reality is altered this way, it's called magic, and the characters who can do it are known as spellcasters.

Each spellcasting class is associated with a certain type of magic: arcane, divine, eldritch, or psionic.

Additionally, there are two special types of spells that certain classes can learn: cantrips and rituals.

### Casting Spells

Spells are cast by replicating necessary hand gestures, spoken words, or other requirements.

-   A character’s class determines the type of magic they use, as well as how they cast spells.
-   A character’s class and level determines how many spells that they can cast in a day.
    -   For some classes, these spell counts are broken down by spell levels.
    -   Casting a cantrip does not count towards the casting limit.
-   The caster must be able to speak and move their hands freely (ex: can't be gagged, bound, or magically silenced).
-   Unless stated otherwise, the target (a specific monster, character, object, or area of effect) must be visible to the caster.
-   The caster must have at least one empty hand (or a magic item in one hand).
-   If in combat, the caster cannot have been hit by an attack or failed a save this round.
-   Additionally, some classes require a [skilled ability check](./adventuring.html#skilled-ability-checks) (or "casting check") to determine the results of the cast.
    -   The spellcasting ability used is determined by the class.

<!--
#### Cantrips

Casting a cantrip requires making a skilled casting check, modified based on the desired effects.

-   On a fumble, a [blunder](#blunders) may occur, and caster's next attempt to cast a cantrip (before a long rest) gets -2.
-   On a failure, the cantrip fizzles, and nothing else happens.
-   On a complicated success, the cantrip is cast, but something interesting (although not directly dangerous) may happen.
-   On a complete success, the cantrip is cast as desired.
-   On a critical success, the cantrip is cast in a notable manner as determined by GM (ex: double duration, range, or targets), and the next casting (before a long rest) gets +2.
-->

<!--
### Countering Spells

Some spell casting classes learn how to cast counter spells, inhibiting the efficacy of an opposing spellcaster.

-   Can only counter same type of magic (arcane, eldritch, or psionic).
-   Can counter a caster of up to 6 levels higher.
-   To counter, make a skilled casting check, modified by -1 for each caster level below target, and +1 for each caster level above target.
-   Counts as spell casting, but:
    -   can be done without being declared at the start of the round, and
    -   can be done as a fallback action when casting another spell (ex: a spell in progress can be abandoned when a caster gains initiative and sees an enemy attempting to cast something worse).
-->

### Memorizing Spells

Some classes memorize spells at the start of each day, and can only cast those spells (although they typically cast them without fail).

-   Takes one hour, can only be done once per day.
-   A character’s class and level determine how many spells they can memorize at one time.
-   The same spell may be memorized more than once, if the character can memorize more than one spell of that level.

### Reading Magic

All spellcasters know [Read Magic](/spells/read-magic.html) as a ritual, taking 10 minutes (1 turn) to cast.

### Spell Effects

-   Some spells affect multiple targets, either by area or by Hit Dice total. If the spell doesn't say how to select the targets, the GM decides.
-   Multiple spells cannot increase the same scores (ex: bonuses to attack rolls, AC, damage rolls, or saves).
    -   Spells that affect different scores can be combined.
    -   Spells can also be combined with the effects of magical items.

#### Concentration

Some spells require the caster's concentration to maintain effect.

-   Performing any other action (including attacking) or moving at greater than half normal rate causes concentration to end.
-   When distracted (ex: damaged by a spell or weapon) while concentrating, the spellcaster must make either a [CHA or CON check](./adventuring.html#ability-checks), with a penalty of 1/2 the damage inflicted (to a max of -4), or the spell ends.

### Alchemy and Potions

Alchemical formulas (for brewing potions or poisons) can be learned and used by anyone with access to the proper equipment.

-   Some arcane spellcasters store learned alchemical formulae within their spellbooks.
-   The difficulty with most potions is in acquiring both the correct formula and ingredients, and then taking the time to brew.

### Magical Research

New spells may be found and learned (or created) via research.

-   All spell casters are assumed to be able to perform magical research.
-   Requires access to information (ex: library, mentor, or another spellbook) .
-   Takes one week and 1000 standard coins per spell level.

#### Copying Spells

When copying an existing spell (ex: using Read Magic on a spell book or scroll):

-   Research time is reduced to one _day_ and 500 standard coins per level, but
-   Upon completion, the GM must make a skilled INT check in secret to determine if the copy is correct.
    -   On a fumble, a [blunder](#blunders) may occur, and the spell fizzles.
        -   Caster must wait until next level of advancement before trying to copy again.
    -   On a failure, an interesting side effect occurs when the spell is cast, but it is beyond repair, and will have to be recopied.
    -   On a complicated success, an interesting side effect occurs when the spell is cast, but it may be fixable.
        -   Roll again after spending 10 minutes (1 turn) fixing it.
    -   On a complete or critical success, the spell works without issue.

### Arcane Magic

Arcane magic comes from written spells, formulae, and procedures known to alter reality.

-   Arcane spellcasters cast spells from their spellbooks.
    -   Either the spellbook, a suitable proxy, or a magic item must be in (or on-)hand while casting.
-   If a spell can be reversed, its form is selected when cast.
-   Spells may be learned via [research](#magical-research).
-   Lost spell books must be rebuilt spell-by-spell, with each spell taking 1 week of game time and 500 standard coins per spell level.
-   Arcane spells written in spellbooks by other spellcasters can only be translated by the Read Magic spell.
-   Arcane casters can use arcane magic items and scrolls.

#### Starting Spells

-   The number of starting spells in a new arcane caster's spell book is based on their Intelligence:

<div class="dividedTableWrapper">

|    INT     | Starting Spells |
| :--------: | :-------------: |
| 12 or less |        1        |
|   13-15    |        2        |
|   16-17    |        3        |
|    18+     |        4        |

[Starting Arcane Spells]

</div>

#### Blunders

Whenever an arcane spellcaster fumbles a spellcasting check, a blunder may occur.

-   Roll on the table below.
-   In the resulting text, roll any dice indicated to determine full effect.
-   Most effects are temporary, lasting 1d6 turns.
    -   Permanent effects are marked.
    -   If the caster fumbles a spellcasting check while still under the effects of a blunder with temporary effects, the blunder becomes a permanent curse.

<div class="dividedTableWrapper">

| d100 |                                                                    Result                                                                     |
| :--: | :-------------------------------------------------------------------------------------------------------------------------------------------: |
|  1   |                                   Target is teleported to where they were exactly 24 hours ago. (permanent)                                   |
|  2   |                                            Caster and target swap locations (reroll if no target).                                            |
|  3   |     Caster is affected as by a [Feeblemind](/spells/feeblemind.html) spell, may **Save vs Spells** at start of each round to end effect.      |
|  4   |                                     Caster is terrified, must **Save vs Spells** or flee for 1d4 minutes.                                     |
|  5   |                                   Caster has migraine, can't attack, move, or cast a spell for 1d4 rounds.                                    |
|  6   |                                            Caster is panicked, can't cast a spell for 1d4 rounds.                                             |
|  7   |                                                  Caster takes 1d8 damage from arcane energy.                                                  |
|  8   |                            Caster sees hallucinations (illusory monsters, horrifying visions, etc) for 1d4 rounds.                            |
|  9   |                                    Caster is dumbfounded, loses ability to speak coherently for 1d4 hours.                                    |
|  10  |                                 Caster is distressed, next attempt to cast a spell today gets additional -2.                                  |
|  11  |                                     Caster is befuddled, loses ability to speak coherently for 1d4 turns.                                     |
|  12  |                                           Caster is distracted, goes last in initiative next round.                                           |
|  13  |                                            Caster has momentary loss of motor skills, falls prone.                                            |
|  14  |     Caster mutates slightly, one of their ability scores (1d6 -> 1: STR, 2: DEX, 3: CON, 4: INT, 5: WIS, 6: CHA) is modified by 1d20-10.      |
|  15  |                                          Caster mutates completely, must reroll all ability scores.                                           |
|  16  |                                   Caster is transformed into a [sentient magic item](#sentient-magic-item).                                   |
|  17  |                      Caster's legs turn into those of a centaur, granting double movement (reroll if already a centaur).                      |
|  18  |                                 Caster's ears mutate: (1d4 -> 1: pointed, 2: floppy, 3: huge, 4: disappear).                                  |
|  19  |                                          Duplicate of caster's face grows on the back of their head.                                          |
|  20  |                                                  1d4 of caster's limbs turn into tentacles.                                                   |
|  21  |                                   1d2 of caster's hands turn into crab claws (dealing 1d4 damage on a hit).                                   |
|  22  |                                Caster's legs turn into the rear of a spider and can move as with spider climb.                                |
|  23  |              Caster's hand gains energy drain (as per a [Wight](/bestiary/wight.html), but creatures killed by it disintegrate).              |
|  24  |                                    Caster gets -1 to any attempt to cast a spell for the rest of the day.                                     |
|  25  |            For a brief moment, caster's mind touches every other mind in the multiverse. _Everyone_ will recognize them on sight.             |
|  26  |                                     Spell leaves scar in caster's mind, and they can never cast it again.                                     |
|  27  |       Spell lodges in caster's mind, can be cast from memory without having it in spellbook, does not count against total known spells.       |
|  28  |                                       Caster's mind is expanded, can cast an additional spell each day.                                       |
|  29  |                 A 1" duplicate of caster pops into existence (with 1 hp, no equipment, and one spell) under caster's control.                 |
|  30  |               A duplicate of caster pops into existence (without equipment), which caster controls (one mind with two bodies).                |
|  31  |             Caster’s shadow becomes a [Shade](/bestiary/shade.html) that (1d2 -> 1: hates caster, 2: is under caster's control).              |
|  32  |                      Arcane energy lashes out from caster dealing 1d6 damage to them and all creatures within 1d4 x 10'.                      |
|  33  |                     A feast for 10 people appears on a large table in front of caster (double wandering monster chance).                      |
|  34  |    A huge tooth-filled maw, 10' in diameter, appears in front of (1d2 -> 1: caster, 2: target), capable of eating anything thrown into it.    |
|  35  |                                                       A wandering monster is summoned.                                                        |
|  36  |             2d6 skeletons appear, armed with short swords, and (1d2 -> 1: they hate caster, 2: they are under caster's control).              |
|  37  |            (1d2 -> 1: Caster, 2: Target)'s hair changes color: (1d6 -> 1: purple, 2: blue, 3: pink, 4: gold, 5: silver, 6: bald).             |
|  38  |          (1d2 -> 1: Caster, 2: Target)'s skin changes color (1d6 -> 1: purple, 2: green, 3: gold, 4: silver, 5: ebony, 6: stripes).           |
|  39  |    (1d2 -> 1: Caster, 2: Target)'s eyes become pitch black as they gain Infravision to 90' (or lose Infravision, if they already had it).     |
|  40  |                                   (1d2 -> 1: Caster, 2: Target)'s age changes by 1d20-10 years. (permanent)                                   |
|  41  |            (1d2 -> 1: Caster, 2: Target)'s head becomes bestial: (1d6 -> 1: snake, 2: goat, 3: bull, 4: rat, 5: insect, 6: fish).             |
|  42  |                (1d2 -> 1: Caster, 2: Target)'s head turns into a (1d4 -> 1: normal, 2: glowing, 3: spiked, 4: flaming) skull.                 |
|  43  | (1d2 -> 1: Caster, 2: Target) gains an extra, fully-functional eye on their (1d4 -> 1: forehead, 2: palm of hand, 3: back of head, 4: chest). |
|  44  |                  (1d2 -> 1: Caster, 2: Target) is (1d4 -> 1: blinded, 2: deafened, 3: paralyzed, 4: stunned) for 1d6 rounds.                  |
|  45  |                                       (1d2 -> 1: Caster, 2: Target)'s height changes by 1d20-10 inches.                                       |
|  46  |                                    (1d2 -> 1: Caster, 2: Target) gains a demonic feature tail, horns, etc.                                    |
|  47  |                     (1d2 -> 1: Caster, 2: Target) gains snake-like features: slitted eyes, can smell with forked tongue.                      |
|  48  |                 (1d2 -> 1: Caster, 2: Target) transforms, gaining (1d4 -> 1: gills, 2: scales, 3: feathers, 4: webbed feet).                  |
|  49  |                                            (1d2 -> 1: Caster, 2: Target) [polymorphs](#polymorph).                                            |
|  50  |                (1d2 -> 1: Caster, 2: Target) is drained of 1 HD (and 1 HD worth of HP). If this kills them, they disintegrate.                |
|  51  |                                A [duplicate](#duplicate) of (1d2 -> 1: caster, 2: target) pops into existence.                                |
|  52  |                             (1d2 -> 1: Caster, 2: Target) begins glowing, casting light as a torch (30' radius).                              |
|  53  |                                  (1d2 -> 1: Caster, 2: Target)'s hair grows by 1d10' (facial hair included).                                  |
|  54  |                         (1d2 -> 1: Caster, 2: Target) becomes undead (stops aging, unable to heal via lawful magic).                          |
|  55  |                                        (1d2 -> 1: Caster, 2: Target) loses 2d10 pounds, gains -1 CON.                                         |
|  56  |                         An anti-magic shell appears around the (1d2 -> 1: caster, 2: target), and can't be dismissed.                         |
|  57  |                                    (1d2 -> 1: Caster, 2: Target)'s tongue turns into that of a giant toad.                                    |
|  58  |                       All of the gold that (1d2 -> 1: caster, 2: target) is carrying is turned into copper (permanent).                       |
|  59  |         All locks within 50' of (1d2 -> 1: caster, 2: target) open automatically, including on doors (regular and secret) and chests.         |
|  60  |            Every magic item that the (1d2 -> 1: caster, 2: target) is carrying that is [drained one die step](#magic-item-drain).             |
|  61  |                Every magic item that the (1d2 -> 1: caster, 2: target) is carrying that has a usage die goes up one die step.                 |
|  62  |        (1d2 -> 1: Caster, 2: Target)'s flesh begins to decay, losing 1d4 HP over the duration of the effect (or per day if permanent).        |
|  63  |                                        (1d2 -> 1: Caster, 2: Target) falls unconscious for 1d4 rounds.                                        |
|  64  |                       (1d2 -> 1: Caster, 2: Target) jumps forward in time, disappearing and reappearing in 1d6 rounds.                        |
|  65  |                             Spell turns into a [breath attack](#breath-attack) for (1d2 -> 1: caster, 2: target).                             |
|  66  |     [Black Tentacles](/spells/black-tentacles.html) appear in a 10' radius centered on the (1d2 -> 1: caster, 2: target) for 1d6 rounds.      |
|  67  |                                (1d2 -> 1: Caster, 2: Target) is [frozen in time](#time-freeze) for 1d4 rounds.                                |
|  68  |                         Everyone but (1d2 -> 1: caster, 2: target) is [frozen in time](#time-freeze) for 1d4 rounds.                          |
|  69  |   Spell creates unearthly sound, all creatures within 100' of (1d2 -> 1: caster, 2: target) must **Save** or flee in terror for 2d8 rounds.   |
|  70  |                                            Spell appears to work, but effects are purely illusory.                                            |
|  71  |                                       Spell is cast, but reversed (reroll if spell can't be reversed).                                        |
|  72  |                                        Spell casts but target changes to a random target within range.                                        |
|  73  |                   Spell casts but effect rebounds onto caster instead (or a random target in range, if caster was target).                    |
|  74  |                 Spell manifests as a ball of energy inside a corked glass bottle, opening or breaking bottle casts the spell.                 |
|  75  |                                     Spell manifests as a [sentient ball of energy](#sentient-spell-ball).                                     |
|  76  |                                                        Calls a [golem](#called-golem)                                                         |
| 77+  |                                                             No additional effect.                                                             |

[Arcane Blunder Table]

</div>

##### Breath Attack

Spell turns into a breath attack for (1d2 -> 1: caster, 2: target), a cone 30' long and 10' wide at far end, which deals 1d6 damage per spell level to everyone caught in it (**Save vs Blasts** for half damage).

##### Called Golem

Calls a (1d8 -> 1: amber, 2: bone, 3: bronze, 4: clay, 5: flesh, 6: iron, 7: stone, 8: wood) golem which will arrive in 1d6 rounds to (1d2 -> 1: serve, 2: destroy) the (1d2 -> 1: caster, 2: target).

##### Duplicate

A duplicate of (1d2 -> 1: Caster, 2: Target) pops into existence exactly the same in every way (including equipment), but with opposite alignment (and always in disagreement with original).

##### Magic Item Drain

Every magic item that the (1d2 -> 1: caster, 2: target) is carrying that has a usage die goes down one die step. If there was only one charge remaining on an item, that charge is lost.

##### Polymorph

(1d2 -> 1: Caster, 2: Target) polymorphs into a creature. Roll 1d10 to determine type:

1. an [al-mir'raj](/bestiary/al-mi-raj.html),
2. a [giant vampire bat](/bestiary/bats/giant-vampire-bat.html),
3. a [giant crab](/bestiary/crab-giant.html),
4. a [war horse](/bestiary/horses/war-horse.html),
5. a [giant scorpion](/bestiary/scorpion-giant.html),
6. an [owl bear](/bestiary/owl-bear.html),
7. a [pteranodon](/bestiary/dinosaurs/pteranodon.html),
8. a [nightmare](/bestiary/nightmare.html),
9. an [ankylosaurus](/bestiary/dinosaurs/ankylosaurus.html),
10. a [gargoyle](/bestiary/gargoyle.html).

<!--
Also
-   Dragon (roll for color / type?)
-   Elemental (roll for size)
-   Golem (roll for type) - what about summoning one as a blunder?
-   Ooze (roll for type)
-   Sky Shark
-   Slime
-   Snake
-   Baboon
-   Batikoda
-   bugbear
-   elephant
-   gelatinous cube
-   mule
-   treant
-   warp-cat
-   watcher
-   wyrmette
-->

##### Sentient Magic Item

Caster is transformed into a sentient magic item which can still talk, but is unable to activate itself.

-   Roll 1d6 to determine magic item type:
    1. a [Broom of Flying](/magic-items/broom-of-flying.html),
    2. a [Chamber of Lightning Bolts](/magic-items/chamber-of-lightning-bolts.html),
    3. a [Drum of Panic](/magic-items/drum-of-panic.html),
    4. a [Rug of Flying](/magic-items/rug-of-flying.html),
    5. a [Horn of Blasting](/magic-items/horn-of-blasting.html),
    6. a Sword +3.
-   May try to **Save vs Spells** once per turn to revert to normal.

##### Sentient Spell Ball

Spell manifests as a sentient ball of energy with HD equal to its level. Roll for reaction to caster. Can cast self at touch range, ceasing to exist.

##### Time Freeze

A creature that is frozen in time:

-   appears to be "fixed" in place;
-   is unable to speak, move, attack, or take any actions;
-   automatically fails any ability check that requires movement or speech;
-   ceases to age; and
-   feels as though they weigh 10x their normal weight.

Attack rolls against a creature frozen in time have [advantage](/rules/basics.html#advantage-and-disadvantage).

### Divine Magic

Divine magic comes from a spellcaster's connection to one or more divine sources (such as gods, nature, or the elements).

-   Divine spellcasters cast spells through prayer to their divine source(s).
    -   When praying for spells, they may choose any spells in their class’ spell list.
-   Divine casters must be faithful to the tenets of their alignment, clergy, class, and/or religion.
    -   If they ever fall out of favor with their divine source, penalties may be imposed (ex: -1 to attack, a reduction in spells, or being sent on a perilous quest).
    -   To regain favor, they would need to perform a great deed for their divine source (GM's choice - ex: donating relics or gold, building a temple, converting others to the religion, etc.).
-   Divine casters can cast reversed versions of spells (possibly gaining disfavor from their divine source).
    -   **Lawful characters**: Only use reversed spells in dire circumstances.
    -   **Chaotic characters**: Usually use reversed spells, only using normal spell versions to benefit their allies.
    -   **Neutral characters**: Usually favor either normal or reversed spells, depending on their divine source.
-   Divine casters can use divine magic items and scrolls.

### Eldritch Magic

Eldritch magic comes from special pacts made between the spellcaster and one or more ancient, powerful beings.

-   Eldritch spellcasters cast spells through the use of ritual invocations to their patrons.
    -   When casting spells, eldritch magicians may choose any spells in their class’ spell list.
-   Eldritch casters must be faithful to their patron.
    -   If they ever fall out of favor with their patron, penalties may be imposed (ex: -1 to eldritch blast damage, a reduction in spells, or being sent on a perilous quest).
    -   To regain favor, they would need to perform a great deed for their patron (GM's choice - ex: collecting an artifact, constructing an altar, vanquishing a powerful enemy of the patron, etc.).
-   Eldritch casters can cast reversed versions of spells, and can use arcane magic items and scrolls.

<!--
### Psionic Magic

Psionic magic comes from a spellcaster's innate ability to alter reality, even if they can't fully control it.

-   Psionic spellcasters begin each day with each of their spells memorized.
-   To cast a spell, a psionic spellcaster must make a [skilled CHA or INT check](./adventuring.html#skilled-ability-checks).

    -   On a fumble, the spell fizzles, [backlash](#backlash) occurs, and next cast (before a long rest) gets -2.
    -   On a failure, the spell fizzles, but nothing else happens.
    -   On a complicated success, the spell is cast, but something interesting (but not directly dangerous) may happen.
    -   On a complete success, the spell is cast as per expected.
    -   On a critical success, the spell is cast in a notable manner as determined by GM (ex: double duration, range, or targets), and next cast (before a long rest) gets +2.

-   Psionic casters can cast reversed versions of spells and can use arcane magic items and scrolls.

#### Backlash

Roll 1d20 on the Backlash Table to see what effect occurs.

<div class="dividedTableWrapper">

| 1d20 |                                                                Effect                                                                 |
| :--: | :-----------------------------------------------------------------------------------------------------------------------------------: |
|  1   | Caster is drained of 1 HD (and 1 HD worth of HP). If this kills them, they disintegrate. Otherwise, it restores after a night's rest. |
|  2   |               Psychic energy lashes out from caster, dealing 1d6 damage to them and the 1d4 creatures nearest to them.                |
|  3   |                 Psychic energy lashes out from caster, dealing 1d6 damage to them and all creatures within 1d4 x 10'.                 |
|  4   |                                             Caster takes 1d8 damage from psychic energy.                                              |
|  5   |         [Black Tentacles](/spells/black-tentacles.html) appear in a 10' radius circle centered on the caster for 1d6 rounds.          |
|  6   |                                    Caster gets -1 to any attempt to cast for the rest of the day.                                     |
|  7   |                                               Caster falls unconscious for 1d4 rounds.                                                |
|  8   |                                        Caster and target swap locations (reroll if no target).                                        |
|  9   |                                 Caster is terrified, must **Save vs Spells** or flee for 1d4 minutes.                                 |
|  10  |                                   Caster has migraine, can't attack, move, or cast for 1d4 rounds.                                    |
|  11  |                                            Caster is panicked, can't cast for 1d4 rounds.                                             |
|  12  |                        Caster sees hallucinations (illusory monsters, horrifying visions, etc) for 1d4 rounds.                        |
|  13  |                                Caster is dumbfounded, loses ability to speak coherently for 1d4 hours.                                |
|  14  |                                 Caster is distressed, next attempt to cast today gets additional -2.                                  |
|  15  |                                 Caster is befuddled, loses ability to speak coherently for 1d4 turns.                                 |
|  16  |                                       Caster is distracted, goes last in initiative next round.                                       |
|  17  |                                        Caster has momentary loss of motor skills, falls prone.                                        |
|  18  |                                    Spell casts but target changes to a random target within range.                                    |
|  19  |               Spell casts but effect rebounds onto caster instead (or a random target in range, if caster was target).                |
|  20  |                                                         No additional effect.                                                         |

</div>
-->

### Ritual Magic

Ritual spells may be cast by performing the ritual as described.

-   Ritual spells are often complicated, taking several minutes (or turns) to cast.
-   Rituals are many and varied - some can even be performed by non-spellcasters (with proper instruction).
-   The power of the ritual is based on several factors, including:
    -   The time spent casting the ritual (with longer rituals being more powerful),
    -   Any sacrifices made as part of the ritual (with willing and/or virginal sacrifices yielding more power), and
    -   Any components used during the ritual (with more powerful rituals requiring rarer or more difficult to obtain components).
-   Some rituals may require a skilled ability check to complete, with the results of the check influencing the outcome of the ritual.

### Magic Saves

Saving throws versus magical effects get an additional modifier, based on the character's Wisdom (WIS).

<div class="dividedTableWrapper">

|  WIS  | Mod |
| :---: | :-: |
|   3   | -3  |
|  4-5  | -2  |
|  6-8  | -1  |
| 9-12  | +0  |
| 13-15 | +1  |
| 16-17 | +2  |
|  18+  | +3  |

[Save vs Magic Modifier]

</div>

### Magic Items

#### Identification

Most magic items can be identified via trial-and-error: using a weapon, wearing a ring, sipping a potion, etc.

-   High-level NPC spellcasters may also identify magic items, typically for a fee or exchange of services.
    -   This may take some time, based on the rituals required (and the spellcaster's schedule).
-   Some powerful magic items (ex: [the Crystal Skull of Jund](/magic-items/crystal-skull-of-jund.html)) are themselves capable of identifying (many) other magic items.

#### Magic Sources

-   Elvish magic items usually have words in elvish etched or carved on them, often the name of the item.
-   Dwarvish magic items usually have runes etched or carved on them.
-   Gnomish magic items usually have their names etched or carved on them in gnomish.

#### Use

Most magic items must be used, worn, or held in the normal way for an object of that type (attacking with a weapon, wearing a ring, etc).

-   Some magic items have continuous magical effects, such as the bonuses on weapons and armor, or most rings.
-   Unless an item's magical effect is continuous, activating a magic item requires its user to spend a combat action concentrating, preventing them from attacking during that round (except as noted).
    -   An item's effect can typically only be activated once per round (except as noted).

#### Usage Die

Some magic items have limited uses, tracked via a **Usage Die**.

-   The item description will indicate the starting die type.
-   After each use, roll the current die, and on a 1-2, the die drops one step (d20 -> d12 -> d10 -> d8 -> d6 -> d4 -> 1) as uses are consumed.
    -   After dropping a die step from a d4, the magic item has only 1 use remaining.
-   When no more uses are left, the item becomes inert.
-   At the GM's discretion, it may be possible to recharge some magic items, increasing the usage die via complex magic rituals.

#### Types

**Armor and Shields**

-   Subject to normal class restrictions on armor and shield usage.

**Miscellaneous Items**

-   May be used by any character (except as noted).
-   May be used any number of times per day (except as noted).

**Potions**

-   May be used by any character (except as noted).
-   May be identified by sipping.
    -   Identifying solely by taste, smell, or appearance can be misleading.
-   Takes 1 round to drink a full dose.
-   Effect of a full dose lasts 1d6+6 turns (except as noted).
    -   GM should roll and track duration in secret.
-   Mixing potions (drinking two with ongoing effects) has the following effects:
    -   The listed effects of both potions are cancelled.
    -   Drinker becomes ill and is disabled for 1d6 turns due to sickness.
    -   Note this doesn't apply to potions with instant / permanent effects (ex: healing).

**Rings**

-   May be used by any character (except as noted).
-   Effect is activated while worn on a finger, thumb, or similar appendage, and is continuously active while worn (except as noted).
-   If more than two rings are worn by a character, the effects of each cease to work (except as noted).
    -   Cursed rings cannot be deactivated in this way.

**Rods**

3' long, 1" diameter solid cylinders, occasionally decorated with runes, glyphs, or other magical accessories.

-   May be used by any character class.
-   Start with [Usage Die](#usage-die) at d8 (except as noted).

**Scrolls**

Aged sheets of paper, parchment, or similar material with magical spells inscribed on them.

-   May be read aloud to cast inscribed spell.
-   In combat, reading a scroll aloud takes 1 round.
-   When read aloud, the words on the scroll disappear.
-   A light source is required to read a scroll aloud.

**Staves**

-   6' long, 2" diameter pole-like items, occasionally decorated with runes, glyphs, or other magical accessories.
-   May only be used by spellcasters (except as noted).
-   Start with [Usage Die](#usage-die) at d12 (except as noted).

**Wands**

-   1.5' long, thin rod-like items, occasionally decorated with runes, glyphs, or other magical accessories.
-   May only be used by non-divine spellcasters (except as noted).
-   Start with [Usage Die](#usage-die) at d10 (except as noted).

**Weapons**

Usage: Per normal class restrictions.

#### Cursed Items

Once a cursed item has been used (ex: in combat), the item's wielder / wearer is taken by the curse and is unable to discard it.

-   They will use the item at every opportunity, including eschewing other, potentially better options.
-   Cursed rings cannot be deactivated by wearing more magical rings.
-   Curse can only be removed with magic (ex: Remove Curse).

#### Sentient Items

A small number of magic items have intelligence and are considered to be sentient.

-   Some sentient items are driven by a particular **purpose**.

<!--
!!! REWRITE to account for elemental and soulbound items.


-->

**Using a Sentient Item**

-   Sentient items are often exceedingly powerful, but can also be dangerous to wield.
-   To activate a sentient item's power:
    -   The item must be in (or on) the wielder's hand, and
    -   The wielder must concentrate to activate the power.

**Alignment**

-   The only way to determine a sentient item's alignment is for someone to touch it.
-   When a character comes in contact with a sentient item, if the character and item have different alignments, the character must **Save vs Spells** each round they're in contact with the weapon or take damage (and possibly lose control to the item, see below).
    -   Chaotic items inflict 1d6 damage per round to lawful-aligned characters.
    -   Lawful items inflict 1d6 damage per round to chaotic-aligned characters.
    -   Neutral items may be used characters of any alignment.

**Exerting Control**

-   A sentient item may try to exert control over its wielder at certain times:
    -   Upon first contact with the wielder,
    -   When the wielder is reduced to half hit points or less,
    -   When the wielder gains another magic item,
    -   If the wielder's alignment differs from that of the item (with each use),
    -   When in a situation involving the item's Purpose.
-   When the item attempts to exert control, the wielder must succeed on a **Save vs Spells** (-2, if wounded or acting in violation of the item's purpose) to prevent it from gaining control.
-   If the item takes control, the GM determines the behavior of the wielder, and may include:
    -   Discarding (or ignoring) other magic items,
    -   Seeking glory for the item by charging into battle,
    -   Surrendering the item to someone it deems more worthy of carrying it (or more susceptible to its control), or
    -   Making improvements to the item (mundane or magical).
-   Once under the control of the item, it will only release the wielder when the circumstances that triggered the item have passed or the item is otherwise satisfied.

!!!include(license/wotc-cc-by.md)!!!
